pub struct Sell {
pub global: Pubkey,
pub fee_recipient: Pubkey,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub associated_bonding_curve: Pubkey,
pub associated_user: Pubkey,
pub user: Pubkey,
pub system_program: Pubkey,
pub associated_token_program: Pubkey,
pub token_program: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for Sell.
Fields
global: Pubkeyfee_recipient: Pubkeymint: Pubkeybonding_curve: Pubkeyassociated_bonding_curve: Pubkeyassociated_user: Pubkeyuser: Pubkeysystem_program: Pubkeyassociated_token_program: Pubkeytoken_program: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Sellwhere
Pubkey: BorshSerialize,
impl BorshSerialize for Sellwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for Sell
impl ToAccountMetas for Sell
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Sell
impl RefUnwindSafe for Sell
impl Send for Sell
impl Sync for Sell
impl Unpin for Sell
impl UnwindSafe for Sell