pub struct SetParams {
pub global: Pubkey,
pub user: Pubkey,
pub system_program: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for SetParams.
Fields
global: Pubkeyuser: Pubkeysystem_program: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SetParamswhere
Pubkey: BorshSerialize,
impl BorshSerialize for SetParamswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SetParams
impl ToAccountMetas for SetParams
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SetParams
impl RefUnwindSafe for SetParams
impl Send for SetParams
impl Sync for SetParams
impl Unpin for SetParams
impl UnwindSafe for SetParams