pub struct Sell {
pub _amount: u64,
pub _min_sol_output: u64,
}Expand description
Instruction.
Fields
_amount: u64_min_sol_output: u64Trait Implementations
Sourceimpl BorshDeserialize for Sellwhere
u64: BorshDeserialize,
impl BorshDeserialize for Sellwhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Sellwhere
u64: BorshSerialize,
impl BorshSerialize for Sellwhere
u64: BorshSerialize,
Sourceimpl Discriminator for Sell
impl Discriminator for Sell
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for Sell
impl InstructionData for Sell