pub struct SetParams {
pub _fee_recipient: Pubkey,
pub _initial_virtual_token_reserves: u64,
pub _initial_virtual_sol_reserves: u64,
pub _initial_real_token_reserves: u64,
pub _token_total_supply: u64,
pub _fee_basis_points: u64,
}Expand description
Instruction.
Fields
_fee_recipient: Pubkey_initial_virtual_token_reserves: u64_initial_virtual_sol_reserves: u64_initial_real_token_reserves: u64_token_total_supply: u64_fee_basis_points: u64Trait Implementations
Sourceimpl BorshDeserialize for SetParams
impl BorshDeserialize for SetParams
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetParams
impl BorshSerialize for SetParams
Sourceimpl Discriminator for SetParams
impl Discriminator for SetParams
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for SetParams
impl InstructionData for SetParams