pub struct BondingCurve {
pub virtual_token_reserves: u64,
pub virtual_sol_reserves: u64,
pub real_token_reserves: u64,
pub real_sol_reserves: u64,
pub token_total_supply: u64,
pub complete: bool,
}Expand description
Account: BondingCurve
Fields
virtual_token_reserves: u64virtual_sol_reserves: u64real_token_reserves: u64real_sol_reserves: u64token_total_supply: u64complete: boolTrait Implementations
Sourceimpl AccountDeserialize for BondingCurve
impl AccountDeserialize for BondingCurve
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for BondingCurve
impl AccountSerialize for BondingCurve
Sourceimpl BorshDeserialize for BondingCurve
impl BorshDeserialize for BondingCurve
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BondingCurve
impl BorshSerialize for BondingCurve
Sourceimpl Clone for BondingCurve
impl Clone for BondingCurve
Sourcefn clone(&self) -> BondingCurve
fn clone(&self) -> BondingCurve
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BondingCurve
impl Default for BondingCurve
Sourcefn default() -> BondingCurve
fn default() -> BondingCurve
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for BondingCurve
impl Discriminator for BondingCurve
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
impl Copy for BondingCurve