pub struct CompleteEvent {
pub user: Pubkey,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub timestamp: i64,
}Fields
user: Pubkeymint: Pubkeybonding_curve: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for CompleteEvent
impl BorshDeserialize for CompleteEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CompleteEvent
impl BorshSerialize for CompleteEvent
Sourceimpl Clone for CompleteEvent
impl Clone for CompleteEvent
Sourcefn clone(&self) -> CompleteEvent
fn clone(&self) -> CompleteEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompleteEvent
impl Debug for CompleteEvent
Sourceimpl Default for CompleteEvent
impl Default for CompleteEvent
Sourcefn default() -> CompleteEvent
fn default() -> CompleteEvent
Returns the “default value” for a type. Read more
impl Copy for CompleteEvent