pub struct CreateEvent {
pub name: String,
pub symbol: String,
pub uri: String,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub user: Pubkey,
}Fields
name: Stringsymbol: Stringuri: Stringmint: Pubkeybonding_curve: Pubkeyuser: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for CreateEvent
impl BorshDeserialize for CreateEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateEvent
impl BorshSerialize for CreateEvent
Sourceimpl Clone for CreateEvent
impl Clone for CreateEvent
Sourcefn clone(&self) -> CreateEvent
fn clone(&self) -> CreateEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateEvent
impl Debug for CreateEvent
Sourceimpl Default for CreateEvent
impl Default for CreateEvent
Sourcefn default() -> CreateEvent
fn default() -> CreateEvent
Returns the “default value” for a type. Read more