pub struct LastWithdraw {
pub last_withdraw_timestamp: i64,
}Fields
last_withdraw_timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for LastWithdrawwhere
i64: BorshDeserialize,
impl BorshDeserialize for LastWithdrawwhere
i64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for LastWithdrawwhere
i64: BorshSerialize,
impl BorshSerialize for LastWithdrawwhere
i64: BorshSerialize,
Sourceimpl Clone for LastWithdraw
impl Clone for LastWithdraw
Sourcefn clone(&self) -> LastWithdraw
fn clone(&self) -> LastWithdraw
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LastWithdraw
impl Debug for LastWithdraw
Sourceimpl Default for LastWithdraw
impl Default for LastWithdraw
Sourcefn default() -> LastWithdraw
fn default() -> LastWithdraw
Returns the “default value” for a type. Read more
impl Copy for LastWithdraw