pub struct SetParamsEvent {
pub fee_recipient: Pubkey,
pub initial_virtual_token_reserves: u64,
pub initial_virtual_sol_reserves: u64,
pub initial_real_token_reserves: u64,
pub token_total_supply: u64,
pub fee_basis_points: u64,
}Fields
fee_recipient: Pubkeyinitial_virtual_token_reserves: u64initial_virtual_sol_reserves: u64initial_real_token_reserves: u64token_total_supply: u64fee_basis_points: u64Trait Implementations
Sourceimpl BorshDeserialize for SetParamsEvent
impl BorshDeserialize for SetParamsEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetParamsEvent
impl BorshSerialize for SetParamsEvent
Sourceimpl Clone for SetParamsEvent
impl Clone for SetParamsEvent
Sourcefn clone(&self) -> SetParamsEvent
fn clone(&self) -> SetParamsEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetParamsEvent
impl Debug for SetParamsEvent
Sourceimpl Default for SetParamsEvent
impl Default for SetParamsEvent
Sourcefn default() -> SetParamsEvent
fn default() -> SetParamsEvent
Returns the “default value” for a type. Read more
impl Copy for SetParamsEvent