pub struct TradeEvent {
pub mint: Pubkey,
pub sol_amount: u64,
pub token_amount: u64,
pub is_buy: bool,
pub user: Pubkey,
pub timestamp: i64,
pub virtual_sol_reserves: u64,
pub virtual_token_reserves: u64,
pub real_sol_reserves: u64,
pub real_token_reserves: u64,
}Fields
mint: Pubkeysol_amount: u64token_amount: u64is_buy: booluser: Pubkeytimestamp: i64virtual_sol_reserves: u64virtual_token_reserves: u64real_sol_reserves: u64real_token_reserves: u64Trait Implementations
Sourceimpl BorshDeserialize for TradeEventwhere
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
bool: BorshDeserialize,
i64: BorshDeserialize,
impl BorshDeserialize for TradeEventwhere
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
bool: BorshDeserialize,
i64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TradeEvent
impl BorshSerialize for TradeEvent
Sourceimpl Clone for TradeEvent
impl Clone for TradeEvent
Sourcefn clone(&self) -> TradeEvent
fn clone(&self) -> TradeEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TradeEvent
impl Debug for TradeEvent
Sourceimpl Default for TradeEvent
impl Default for TradeEvent
Sourcefn default() -> TradeEvent
fn default() -> TradeEvent
Returns the “default value” for a type. Read more
impl Copy for TradeEvent